//===============================================
// DragonFireSDK.h
//===============================================
#include <stdio.h>

#pragma comment(lib,"C:/DragonFireSDK/DragonFireSDK.lib")

//===============================================
// App.cpp must provide these functions
void AppMain(); // app starts here
void OnTimer(); // 30 times per sec - update game here
void AppExit(); // app ends here - save game if desired

//===============================================


int WorldSetxy(int x,int y);

int ImageAdd(char *filename);
int ImageGetWidth(int im);
int ImageGetHeight(int im);

int ViewAdd(int im,int x,int y);
int ViewAdd(char *filename,int x,int y);
int ViewAdd(char *filename,int x,int y,int (*callback)(int id,int event,int x,int y),int id);

int ViewGetx(int vw);
int ViewGety(int vw);
int ViewGetWidth(int vw);
int ViewGetHeight(int vw);

int ViewSetxy(int vw,int x,int y);
int ViewSetImage(int vw,int im);
int ViewSetVisible(int vw,int flag);

int TouchAdd(int x,int y,int width,int height,int (*callback)(int id,int event,int x,int y),int id); // event: 1=down, 2=move, 3=up
int TouchGetxy(int tc,int &x,int &y);
int TouchSetxy(int tc,int x,int y);
int TouchSetVisible(int tc,int flag);

void RandomSetSeed(unsigned int seed);
void Randomize();
int Random(unsigned int range); // ret number from 0 to <range

int ButtonAdd(char *filename,int x,int y,int (*callback)(int id),int id);
int ButtonSetVisible(int bt,int flag);

int PushButtonAdd(char *filename,int x,int y,int (*callback)(int id),int id);
int PushButtonSetVisible(int bt,int flag);

int FontAdd(char *foldername);
int FontAdd(char *font,char *style,int points,int color);
//  Arial
//  Courier
//  Georgia
//  Helvetica
//  Times
//  Trebuchet
//  Verdana

int TextAdd(int x,int y,char *text,int font);
int TextSetText(int tx,char *text);
int TextGetText(int tx,char *text);
int TextSetxy(int tx,int x,int y);
int TextGetx(int tx);
int TextGety(int tx);
int TextSetVisible(int tx,int flag);
int TextSetColor(int tx,int color);

int FileOpenAsset(char *filename);
int FileOpen(char *filename);
int FileCreate(char *filename);
int FileRead(int fh,char *buf,int len);
int FileWrite(int fh,char *buf,int len);
int FileSeek(int fh,int seek);
int FileClose(int fh);
int FileDelete(char *filename);	// 1.4

int SoundAdd(char *filename);
int SoundPlay(int sn);
int SoundLoop(int sn);
int SoundStop(int sn);

int Mp3Add(char *filename);
int Mp3Play(int sn);
int Mp3Loop(int sn);
int Mp3Stop(); // only one that can be playing so sn not needed


void DeckShuffle(int deck[52]);

void Printf(char* lpszFormat, ...);

void StrCopy(char *dest,char *src);
void StrAppend(char *dest,char *src);

void LandscapeMode();
void PortraitMode();

int ViewSetRotate(int vw,int degrees);
int ViewSetSize(int vw,int width,int height);

int ViewSetTouch(int vw,int tc);

int TiltGetx();
int TiltGety();
int TiltGetz();

int ViewSetAlpha(int vw,int alpha);

int EditAdd(int x,int y,int width);
int EditSetLabel(int ed,char *text);
int EditSetText(int ed,char *text);
int EditGetText(int ed,char *text);
int EditSetVisible(int ed,int flag);
int EditSetOnDone(int (*callback)(void));
int EditSetKeyboard(int ed,int flag);
int EditSetFocus(int ed,int flag);

int DrawAdd(int x,int y,int width,int height);
int DrawSetVisible(int dr, int flag);
int DrawSetxy(int dr, int x,int y);

int DrawClear(int dr); // handle to drawing surface from DrawAdd
int DrawSetPenWidth(int dr,int width);
int DrawSetColor(int dr,int color);
int DrawSetFillColor(int dr,int color);
int DrawMoveTo(int dr,int x,int y);
int DrawLineTo(int dr,int x,int y);
int DrawCurveTo(int dr,int x,int y);
int DrawFill(int dr); // (uses draw color) from pt inside?
int DrawSquare(int dr,int x,int y,int width,int height); // or Rectangle
int DrawSquareFill(int dr,int x,int y,int width,int height); // or Rectangle
int DrawCircle(int dr,int x,int y,int width,int height); // or Ellipse
int DrawCircleFill(int dr,int x,int y,int width,int height); // or Ellipse
int DrawLine(int dr,int x1,int y1,int x2,int y2);
int DrawArc(int dr,int x,int y,int radius,int begin,int end);
int DrawPoly(int dr,int *points);
int DrawPolyFill(int dr,int *points);

int BitmapAdd(int x,int y,int width,int height);
int BitmapSetVisible(int bi,int flag);
unsigned char *BitmapGetBits(int bi);
int BitmapUpdate(int bi); // notify sys that bits have changed
void BitmapSetPixel(int bi,int x,int y,int r,int g,int b,int a);
void BitmapSetPixel(int bi,int x,int y,int color); // color=0xBBGGRRAA premultiplied bgr with alpha (iphone native)
int BitmapSetxy(int bi,int x,int y);
int BitmapSetImage(int bi,int im);

int LcdStayOn(int flag);

int NetSend(char *url,int (*callback)(int event,char *response,int len)); // event: 0=failed, 1=success

unsigned int TimerGetMsExpired();
unsigned int TimerGetMs();

int DirBegin(char *value,char *ext);
int DirNext(char *value, int len);
int DirEnd();

int AutoRotateInit(int allow,int (*callback)(int)); // allow 0=none,1=portrait, 2=landscape, 3=both - call this last in AppMain so all images and views avail

int ButtonSetxy(int bt,int x,int y);
int PushButtonSetxy(int bt,int x,int y);

void Vibrate();

int LocationGet(float &lat, float &lng);
void LocationMonitorLocation(int flag);
void LocationMonitorHeading(int flag);
float LocationDistanceFrom(float lat, float lng);
float LocationDistanceBetween(float lat1, float lng1,float lat2, float lng2);
float LocationGetAltitude();
float LocationGetHorizontalAccuracy();	
float LocationGetVerticalAccuracy();	
float LocationGetCourse();	
float LocationGetSpeed();	
float LocationGetHeading();


int AdBannerInit(int location);	// 0=top, 1=bottom
int AdBannerSetLocation(int location); // 0=top, 1=bottom
int AdBannerSetVisible(int flag);

int DeviceGetBatteryLevel();
int DeviceGetBatteryState();
int DeviceGetModel(char *value, int len);
int DeviceGetName(char *value, int len);
int DeviceGetSystemName(char *value, int len);
int DeviceGetSystemVersion(char *value, int len);
int DeviceGetUDID(char *value, int len);
void DeviceSetBatteryMonitoring(int flag);
int DeviceGetMultitaskingSupported();
int DeviceGetLocaleID(char *value, int len);
int DeviceGetUIType();

int BrowserLaunch(char *url);

// use ViewSetImage instead of ImageSetImage in most cases - see Help
int ImageSetImage(int im,char *filename); // reuse an image (from ImageAdd) deleting old one

// use printf (not Printf) to display in Visual Studio output window for debugging
#define printf Printf
